@@ -3,7 +3,7 @@
 
 """HDFS clients."""
 
-from .util import Config, HdfsError
+from .util import HdfsError
 from getpass import getuser
 from os.path import exists, isdir, join
 from requests_kerberos import HTTPKerberosAuth, OPTIONAL
@@ -87,7 +87,9 @@ class _ClientType(type):
     for key, value in attrs.items():
       if isinstance(value, _Request):
         attrs[key] = value.to_method(mcs.pattern.sub('', key).upper())
-    return super(_ClientType, mcs).__new__(mcs, name, bases, attrs)
+    client = super(_ClientType, mcs).__new__(mcs, name, bases, attrs)
+    client.__registry__[client.__name__] = client
+    return client
 
 
 class Client(object):
@@ -110,7 +112,7 @@ class Client(object):
   """
 
   __metaclass__ = _ClientType
-
+  __registry__ = {}
   _root = None
 
   def __init__(self, url, auth=None, params=None, proxy=None, root=None):
@@ -122,6 +124,23 @@ class Client(object):
     if root and root != '/':
       self._root = root.rstrip('/')
 
+  @classmethod
+  def load(cls, class_name, options):
+    """Load client from options.
+
+    :param class_name: Client class name. Pass `None` for the base
+      :class:`Client` class.
+    :param options: Options dictionary.
+
+    """
+    class_name = class_name or 'Client'
+    try:
+      return cls.__registry__[class_name](**options)
+    except KeyError:
+      raise HdfsError('Unknown client class: %r', class_name)
+    except TypeError:
+      raise HdfsError('Invalid options: %r', options)
+
   def _abs(self, path):
     """Return absolute path.
 
@@ -294,8 +313,11 @@ class Client(object):
     :param depth: Maximum depth to explore directories.
     :param usage: Include summary content usage for directories.
 
-    This method returns a generator containing FileStatus_ (and optionally,
-    ContentSummary_) JSON objects.
+    This method returns a generator yielding tuples `(path, status, summary)`
+    where `path` is the relative path to the current file or directory,
+    `status` is a JSON FileStatus_ object, and `summary` a JSON ContentSummary_
+    object if `path` points to a directory and `usage=True` and `None`
+    otherwise.
 
     .. _FileStatus: FS_
     .. _ContentSummary: CS_
@@ -304,13 +326,13 @@ class Client(object):
 
     """
     status = self._get_file_status(hdfs_path).json()['FileStatus']
-    def _walk(dir_path, status, depth):
+    def _walk(dir_path, dir_status, depth):
       """Recursion helper."""
       if usage:
         summary = self._get_content_summary(dir_path).json()['ContentSummary']
       else:
         summary = None
-      yield dir_path, status, summary
+      yield dir_path, dir_status, summary
       if depth > 0:
         statuses = self._list_status(dir_path).json()['FileStatuses']
         for status in statuses['FileStatus']:
@@ -318,9 +340,8 @@ class Client(object):
           if status['type'] == 'FILE':
             yield path, status, None
           else: # directory
-            if depth > 0:
-              for a in _walk(path, status, depth - 1):
-                yield a
+            for a in _walk(path, status, depth - 1):
+              yield a
     if status['type'] == 'FILE':
       yield hdfs_path, status, None
     else:
@@ -359,8 +380,7 @@ class KerberosClient(Client):
   :param url: Hostname or IP address of HDFS namenode, prefixed with protocol,
     followed by WebHDFS port on namenode
   :param proxy: User to proxy as.
-  :param root: Root path. Used to allow relative path parameters. Defaults to
-    the current user's (as determined by `whoami`) home directory on HDFS.
+  :param root: Root path. Used to allow relative path parameters.
 
   """
 
@@ -369,7 +389,7 @@ class KerberosClient(Client):
       url,
       auth=HTTPKerberosAuth(OPTIONAL),
       proxy=proxy,
-      root=root or '/user/%s/' % (getuser(), ),
+      root=root,
     )
 
   def _on_error(self, response):
@@ -393,8 +413,7 @@ class TokenClient(Client):
     followed by WebHDFS port on namenode
   :param token: Hadoop delegation token.
   :param proxy: User to proxy as.
-  :param root: Root path. Used to allow relative path parameters. Defaults to
-    the current user's (as determined by `whoami`) home directory on HDFS.
+  :param root: Root path. Used to allow relative path parameters.
 
   """
 
@@ -403,26 +422,5 @@ class TokenClient(Client):
       url=url,
       params={'delegation': token},
       proxy=proxy,
-      root=root or '/user/%s/' % (getuser(), ),
+      root=root,
     )
-
-
-def get_client_from_alias(alias):
-  """Load client corresponding to an alias.
-
-  :param alias: Alias name.
-
-  """
-  options = Config().get_alias(alias)
-  auth = options.pop('auth')
-  try:
-    if auth == 'insecure':
-      return InsecureClient(**options)
-    elif auth == 'kerberos':
-      return KerberosClient(**options)
-    elif auth == 'token':
-      return TokenClient(**options)
-    else:
-      raise HdfsError('Invalid auth parameter %r for alias %r.', auth, alias)
-  except ValueError:
-    raise HdfsError('Invalid alias %r.', alias)
