@@ -3,6 +3,7 @@
 
 """Test Hdfs client interactions with HDFS."""
 
+from hdfs import get_client_from_alias
 from hdfs.util import Config, temppath
 from hdfs.client import *
 from ConfigParser import NoOptionError, NoSectionError
@@ -21,6 +22,39 @@ def status(response):
   return response.json()['boolean']
 
 
+class TestLoad(object):
+
+  """Test client loader."""
+
+  def test_bare(self):
+    client = Client.load(None, {'url': 'foo'})
+    ok_(isinstance(client, Client))
+
+  def test_kerberos(self):
+    client = Client.load('KerberosClient', {'url': 'foo'})
+    ok_(isinstance(client, KerberosClient))
+
+  def test_new_type(self):
+    class NewClient(Client):
+      def __init__(self, url, bar):
+        super(NewClient, self).__init__(url)
+        self.bar = bar
+    client = Client.load('NewClient', {'url': 123, 'bar': 2})
+    eq_(client.bar, 2)
+
+  @raises(HdfsError)
+  def test_missing_options(self):
+    client = Client.load('KerberosClient', {})
+
+  @raises(HdfsError)
+  def test_invalid_options(self):
+    client = Client.load(None, {'foo': 123})
+
+  @raises(HdfsError)
+  def test_missing_type(self):
+    client = Client.load('foo', {})
+
+
 class _TestSession(object):
 
   """Base class to run tests using remote HDFS.
@@ -42,7 +76,7 @@ class _TestSession(object):
   @classmethod
   def setup_class(cls):
     try:
-      client = get_client_from_alias(Config().parser.get('hdfs', 'test.alias'))
+      client = get_client_from_alias('test')
       client._delete('', recursive=True)
     except (NoOptionError, NoSectionError, HdfsError):
       cls.client = None
@@ -298,7 +332,7 @@ class TestRename(_TestSession):
     self._check_content('bar/foo', 'hello, world!')
 
 
-class TestInfo(_TestSession):
+class TestWalk(_TestSession):
 
   def test_file(self):
     self.client.write('foo', 'hello, world!')
